@@ -8,7 +8,7 @@
 
 #include "aspi.h"
 
-#if defined(WIN32) || defined(__i386__)
+#if defined(WIN32) || defined(__i386__) || defined(__x86_64__)
 #define BIT_FIELDS_LTOH	/* Intel */
 #endif
 
