@@ -3,7 +3,8 @@ cd ../common
 
 for fn in *.c *.h; do
   echo Converting $fn to sjis...
-  nkf -s -Lw $fn > tmp
-  mv tmp $fn
+  iconv -f EUCJP -t MS932 $fn -o $fn.new \
+	&& mv $fn.new $fn \
+	|| rm -f $fn.new
 done
 
