@@ -144,13 +144,14 @@ CEnbanKensaDlg::CEnbanKensaDlg(CWnd* pParent /*=NULL*/)
 	::ZeroMemory(&m_Drawable, sizeof(m_Drawable));
 	m_bmpLogo.LoadBitmap(IDB_LOGO);
 	m_bmpLogoMask.LoadBitmap(IDB_LOGOMASK);
-
+	m_pDiscInfoDlg = NULL;
 }
 
 void CEnbanKensaDlg::DoDataExchange(CDataExchange* pDX)
 {
 	CDialog::DoDataExchange(pDX);
 	//{{AFX_DATA_MAP(CEnbanKensaDlg)
+	DDX_Control(pDX, IDC_BTN_DISCINFO, m_BtnDiscInfo);
 	DDX_Control(pDX, IDC_STC_INFO, m_StcInfo);
 	DDX_Control(pDX, IDC_STC_DRAWAREA, m_StcDrawArea);
 	DDX_Control(pDX, IDOK, m_BtnOK);
@@ -164,6 +165,7 @@ BEGIN_MESSAGE_MAP(CEnbanKensaDlg, CDialog)
 	ON_WM_SYSCOMMAND()
 	ON_WM_PAINT()
 	ON_WM_QUERYDRAGICON()
+	ON_BN_CLICKED(IDC_BTN_DISCINFO, OnBtnDiscinfo)
 	//}}AFX_MSG_MAP
 	ON_MESSAGE(WM_KICKIDLE, OnKickIdle)
 	ON_MESSAGE(WM_USER_UICTL, OnUICtl)
@@ -209,7 +211,8 @@ BOOL CEnbanKensaDlg::OnInitDialog()
 	RECT rect;
 	m_StcDrawArea.GetClientRect(&rect);
 	CreateDrawable(rect.right-rect.left, rect.bottom-rect.top);
-	m_BtnOK.SetWindowText("Jn");
+	m_BtnOK.SetWindowText("ǎ挟");
+	m_BtnDiscInfo.SetWindowText("~Տ");
 
 	return TRUE;  // TRUE ԂƃRg[ɐݒ肵tH[JX͎܂B
 }
@@ -289,7 +292,6 @@ void CEnbanKensaDlg::OnOK()
 	//CDialog::OnOK();
 	if(m_bRunning){
 		UISetAbort();
-		m_bRunning = FALSE;
 		m_BtnOK.EnableWindow(FALSE);
 		return;
 	}
@@ -303,6 +305,12 @@ void CEnbanKensaDlg::OnOK()
 	if(sel_drive == CB_ERR)
 		return;
 
+	if(m_pDiscInfoDlg != NULL){
+		m_pDiscInfoDlg->DestroyWindow();
+		delete m_pDiscInfoDlg;
+		m_pDiscInfoDlg = NULL;
+	}
+
 	drive.hid = m_pDrives[sel_drive].hid;
 	drive.tid = m_pDrives[sel_drive].tid;
 
@@ -311,12 +319,14 @@ void CEnbanKensaDlg::OnOK()
 	m_BtnOK.SetWindowText("f");
 	m_BtnOK.SetFocus();
 	m_CmbDrive.EnableWindow(FALSE);
+	m_BtnDiscInfo.EnableWindow(FALSE);
 	m_bRunning = TRUE;
 
 	ret = CheckDisc(&drive);
 
-	m_BtnOK.SetWindowText("Jn");
+	m_BtnOK.SetWindowText("ǎ挟");
 	m_BtnOK.EnableWindow(TRUE);
+	m_BtnDiscInfo.EnableWindow(TRUE);
 	m_CmbDrive.EnableWindow(TRUE);
 	m_bRunning = FALSE;
 }
@@ -491,6 +501,7 @@ void CEnbanKensaDlg::LoadTheme()
 	pThemeClass->InitializeTheme();
 	pThemeClass->LoadThemeFromStruct(theme);
 	m_BtnOK.SetTheme(pThemeClass);
+	m_BtnDiscInfo.SetTheme(pThemeClass);
 	m_StcDrive.SetTheme(pThemeClass);
 	m_CmbDrive.SetTheme(pThemeClass);
 	m_StcInfo.SetTheme(pThemeClass);
@@ -553,6 +564,11 @@ BOOL CEnbanKensaDlg::DestroyWindow()
 		free(m_pDrives);
 		m_pDrives = NULL;
 	}
+	if(m_pDiscInfoDlg != NULL){
+		m_pDiscInfoDlg->DestroyWindow();
+		delete m_pDiscInfoDlg;
+		m_pDiscInfoDlg = NULL;
+	}
 	DestroyDrawable();
 	return CDialog::DestroyWindow();
 }
@@ -585,6 +601,9 @@ LRESULT CEnbanKensaDlg::OnUICtl(WPARAM wParam, LPARAM lParam)
 		break;
 	case UICTL_SETTING:
 		return Setting((OPTIONS *)lParam);
+	case UICTL_DISCINFO:
+		DispDiscInfo((UIDISCINFO *)lParam);
+		break;
 	}
 
 	return 0;
@@ -757,3 +776,53 @@ int CEnbanKensaDlg::Setting(OPTIONS *pOption)
 	return ret==IDOK ? RET_OK : RET_ABORT;
 }
 
+
+void CEnbanKensaDlg::DispDiscInfo(UIDISCINFO *pDiscInfo)
+{
+	if(m_pDiscInfoDlg == NULL){
+		m_pDiscInfoDlg = new CDiscInfoDlg(&m_StcDrawArea);
+		m_pDiscInfoDlg->Create(IDD_DISCINFO, &m_StcDrawArea);
+		m_pDiscInfoDlg->SetTheme(GetTheme());
+		m_pDiscInfoDlg->ShowWindow(SW_SHOWNORMAL);
+	}
+	m_pDiscInfoDlg->SetData(pDiscInfo);
+}
+
+
+void CEnbanKensaDlg::OnBtnDiscinfo() 
+{
+	// TODO: ̈ʒuɃRg[ʒmnhp̃R[hǉĂ
+	if(m_bRunning){
+		UISetAbort();
+		m_BtnDiscInfo.EnableWindow(FALSE);
+		return;
+	}
+
+	DRIVEID drive;
+	int sel_drive;
+//	int ret;
+
+	/* IhCu擾 */
+	sel_drive = m_CmbDrive.GetCurSel();
+	if(sel_drive == CB_ERR)
+		return;
+
+	drive.hid = m_pDrives[sel_drive].hid;
+	drive.tid = m_pDrives[sel_drive].tid;
+
+	UIClearAbort();
+	UISetHWND(this->m_hWnd);
+	m_BtnDiscInfo.SetWindowText("f");
+	m_BtnOK.EnableWindow(FALSE);
+	m_CmbDrive.EnableWindow(FALSE);
+	m_bRunning = TRUE;
+	UICheckAbort();
+
+	DisplayDiscInformation(&drive);
+
+	m_BtnDiscInfo.SetWindowText("~Տ");
+	m_BtnDiscInfo.EnableWindow(TRUE);
+	m_BtnOK.EnableWindow(TRUE);
+	m_CmbDrive.EnableWindow(TRUE);
+	m_bRunning = FALSE;
+}
