@@ -1,4 +1,4 @@
-/* ~Օʉ - EnbanKensa
+/* ~Ռ - EnbanKensa
  * Copyright (C) 2005 Kagetani Hideto
  */
 #ifndef __UI_H__
@@ -11,6 +11,22 @@
 extern "C" {
 #endif
 
+typedef struct {
+  WORD session;
+  WORD track;
+  DWORD start_lba;
+  DWORD end_lba;
+  DWORD blocks;
+  DWORD packet_size;
+  char *mode;
+  char *comment;
+} UITRACKINFO;
+
+typedef struct {
+  UITRACKINFO *track_info;
+  WORD tracks;
+} UIDISCINFO;
+
 typedef struct {
 	unsigned short red;
 	unsigned short green;
@@ -24,6 +40,7 @@ typedef struct {
 #define UICTL_DRAWTEXT		4
 #define UICTL_GETDRAWABLESIZE	5
 #define UICTL_SETTING			6
+#define UICTL_DISCINFO		7
 
 extern void UISetHWND(HWND hWnd);
 extern BOOL UICheckAbort();
@@ -38,12 +55,13 @@ extern int UIDispMessage(const char *message, int type);
 #define UIDMRET_OK		0
 #define UIDMRET_CANCEL	1
 
-extern void UIDispInfo(const char *message);
+extern void UIDispInfo(const char *message, ...);
 extern void UIDrawLine(int x0, int y0, int x1, int y1, const UICOLOR *color);
 extern void UIDrawBox(int x0, int y0, int x1, int y1, const UICOLOR *color, BOOL fill);
 extern void UIDrawText(int x0, int y0, const UICOLOR *color, const char *text);
 extern void UIGetDrawableSize(int *width, int *height);
 extern int UISetting(OPTIONS *option);
+extern void UIDispDiscInfo(UITRACKINFO *uiTrackInfo, int num_track);
 
 #ifdef __cplusplus
 }
